@@ -13,16 +13,7 @@ use List::Util qw( reduce );
 use POSIX ":sys_wait_h";
 use constant STATUS  => qw( exit signal core );
 
-our $VERSION = '1.04';
-
-# Trap the real STDIN/ERR/OUT file handles in case someone
-# *COUGH* Catalyst *COUGH* screws with them which breaks open3
-my ($REAL_STDIN, $REAL_STDOUT, $REAL_STDERR);
-BEGIN {
-    open $REAL_STDIN, "<&=".fileno(*STDIN);
-    open $REAL_STDOUT, ">>&=".fileno(*STDOUT);
-    open $REAL_STDERR, ">>&=".fileno(*STDERR);
-}
+our $VERSION = '1.06';
 
 our $QUIET = 0;
 
@@ -53,11 +44,6 @@ my $_spawn = sub {
     my (@cmd) = @_;
     my ( $pid, $in, $out, $err );
 
-    # save standard handles
-    local *STDIN  = $REAL_STDIN;
-    local *STDOUT = $REAL_STDOUT;
-    local *STDERR = $REAL_STDERR;
-
     # setup filehandles
     {
         no strict 'refs';
@@ -142,7 +128,7 @@ sub new {
 
 sub spawn {
     my ( $class, @cmd ) = @_;
-    return @{ System::Command->new(@cmd) }{qw( pid stdin stdout stderr )};
+    return @{ $class->new(@cmd) }{qw( pid stdin stdout stderr )};
 }
 
 sub is_terminated {
@@ -281,7 +267,7 @@ an exception.
 =back
 
 If several option hashes are passed to C<new()>, they will be merged
-together with individual values being overriden by those (with the same
+together with individual values being overridden by those (with the same
 key) from hashes that appear later in the list.
 
 The C<System::Command> object returned by C<new()> has a number of
